@@ -8,6 +8,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
 from .. import (
@@ -32,11 +34,11 @@ class CircleCiProps:
     def __init__(
         self,
         *,
-        jobs: typing.Optional[typing.Sequence["Job"]] = None,
+        jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[str, typing.Any]]]] = None,
         orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         setup: typing.Optional[builtins.bool] = None,
         version: typing.Optional[jsii.Number] = None,
-        workflows: typing.Optional[typing.Sequence["Workflow"]] = None,
+        workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''(experimental) Options for class {@link Circleci}.
 
@@ -49,6 +51,13 @@ class CircleCiProps:
         :see: https://circleci.com/docs/2.0/configuration-reference/
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CircleCiProps.__init__)
+            check_type(argname="argument jobs", value=jobs, expected_type=type_hints["jobs"])
+            check_type(argname="argument orbs", value=orbs, expected_type=type_hints["orbs"])
+            check_type(argname="argument setup", value=setup, expected_type=type_hints["setup"])
+            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
+            check_type(argname="argument workflows", value=workflows, expected_type=type_hints["workflows"])
         self._values: typing.Dict[str, typing.Any] = {}
         if jobs is not None:
             self._values["jobs"] = jobs
@@ -139,11 +148,11 @@ class Circleci(
         self,
         project: _Project_57d89203,
         *,
-        jobs: typing.Optional[typing.Sequence["Job"]] = None,
+        jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[str, typing.Any]]]] = None,
         orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         setup: typing.Optional[builtins.bool] = None,
         version: typing.Optional[jsii.Number] = None,
-        workflows: typing.Optional[typing.Sequence["Workflow"]] = None,
+        workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param project: -
@@ -155,6 +164,9 @@ class Circleci(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Circleci.__init__)
+            check_type(argname="argument project", value=project, expected_type=type_hints["project"])
         options = CircleCiProps(
             jobs=jobs, orbs=orbs, setup=setup, version=version, workflows=workflows
         )
@@ -172,6 +184,10 @@ class Circleci(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Circleci.add_orb)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument orb", value=orb, expected_type=type_hints["orb"])
         return typing.cast(None, jsii.invoke(self, "addOrb", [name, orb]))
 
     @jsii.member(jsii_name="addWorkflow")
@@ -179,8 +195,8 @@ class Circleci(
         self,
         *,
         identifier: builtins.str,
-        jobs: typing.Optional[typing.Sequence["WorkflowJob"]] = None,
-        triggers: typing.Optional[typing.Sequence["Triggers"]] = None,
+        jobs: typing.Optional[typing.Sequence[typing.Union["WorkflowJob", typing.Dict[str, typing.Any]]]] = None,
+        triggers: typing.Optional[typing.Sequence[typing.Union["Triggers", typing.Dict[str, typing.Any]]]] = None,
         when: typing.Any = None,
     ) -> None:
         '''(experimental) add new workflow to existing pipeline.
@@ -249,6 +265,16 @@ class Docker:
         :see: https://circleci.com/docs/2.0/configuration-reference/#docker
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Docker.__init__)
+            check_type(argname="argument image", value=image, expected_type=type_hints["image"])
+            check_type(argname="argument auth", value=auth, expected_type=type_hints["auth"])
+            check_type(argname="argument aws_auth", value=aws_auth, expected_type=type_hints["aws_auth"])
+            check_type(argname="argument command", value=command, expected_type=type_hints["command"])
+            check_type(argname="argument entrypoint", value=entrypoint, expected_type=type_hints["entrypoint"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument user", value=user, expected_type=type_hints["user"])
         self._values: typing.Dict[str, typing.Any] = {
             "image": image,
         }
@@ -365,8 +391,8 @@ class Filter:
     def __init__(
         self,
         *,
-        branches: typing.Optional["FilterConfig"] = None,
-        tags: typing.Optional["FilterConfig"] = None,
+        branches: typing.Optional[typing.Union["FilterConfig", typing.Dict[str, typing.Any]]] = None,
+        tags: typing.Optional[typing.Union["FilterConfig", typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) The branches key controls whether the current branch should have a schedule trigger created for it, where current branch is the branch containing the config.yml file with the trigger stanza. That is, a push on the main branch will only schedule a workflow for the main branch.
 
@@ -389,6 +415,10 @@ class Filter:
             branches = FilterConfig(**branches)
         if isinstance(tags, dict):
             tags = FilterConfig(**tags)
+        if __debug__:
+            type_hints = typing.get_type_hints(Filter.__init__)
+            check_type(argname="argument branches", value=branches, expected_type=type_hints["branches"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {}
         if branches is not None:
             self._values["branches"] = branches
@@ -443,6 +473,10 @@ class FilterConfig:
         :see: https://circleci.com/docs/2.0/configuration-reference/#filters
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FilterConfig.__init__)
+            check_type(argname="argument ignore", value=ignore, expected_type=type_hints["ignore"])
+            check_type(argname="argument only", value=only, expected_type=type_hints["only"])
         self._values: typing.Dict[str, typing.Any] = {}
         if ignore is not None:
             self._values["ignore"] = ignore
@@ -501,12 +535,12 @@ class Job:
         self,
         *,
         identifier: builtins.str,
-        docker: typing.Optional[typing.Sequence[Docker]] = None,
+        docker: typing.Optional[typing.Sequence[typing.Union[Docker, typing.Dict[str, typing.Any]]]] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
-        machine: typing.Optional["Machine"] = None,
-        macos: typing.Optional["Macos"] = None,
+        machine: typing.Optional[typing.Union["Machine", typing.Dict[str, typing.Any]]] = None,
+        macos: typing.Optional[typing.Union["Macos", typing.Dict[str, typing.Any]]] = None,
         parallelism: typing.Optional[jsii.Number] = None,
-        parameters: typing.Optional[typing.Mapping[builtins.str, "PipelineParameter"]] = None,
+        parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union["PipelineParameter", typing.Dict[str, typing.Any]]]] = None,
         resource_class: typing.Optional[builtins.str] = None,
         shell: typing.Optional[builtins.str] = None,
         steps: typing.Optional[typing.Sequence[typing.Any]] = None,
@@ -538,6 +572,19 @@ class Job:
             machine = Machine(**machine)
         if isinstance(macos, dict):
             macos = Macos(**macos)
+        if __debug__:
+            type_hints = typing.get_type_hints(Job.__init__)
+            check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
+            check_type(argname="argument docker", value=docker, expected_type=type_hints["docker"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument machine", value=machine, expected_type=type_hints["machine"])
+            check_type(argname="argument macos", value=macos, expected_type=type_hints["macos"])
+            check_type(argname="argument parallelism", value=parallelism, expected_type=type_hints["parallelism"])
+            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
+            check_type(argname="argument resource_class", value=resource_class, expected_type=type_hints["resource_class"])
+            check_type(argname="argument shell", value=shell, expected_type=type_hints["shell"])
+            check_type(argname="argument steps", value=steps, expected_type=type_hints["steps"])
+            check_type(argname="argument working_directory", value=working_directory, expected_type=type_hints["working_directory"])
         self._values: typing.Dict[str, typing.Any] = {
             "identifier": identifier,
         }
@@ -733,6 +780,10 @@ class Machine:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Machine.__init__)
+            check_type(argname="argument image", value=image, expected_type=type_hints["image"])
+            check_type(argname="argument docker_layer_caching", value=docker_layer_caching, expected_type=type_hints["docker_layer_caching"])
         self._values: typing.Dict[str, typing.Any] = {
             "image": image,
         }
@@ -790,6 +841,9 @@ class Macos:
         :see: https://circleci.com/docs/2.0/configuration-reference/#macos
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Macos.__init__)
+            check_type(argname="argument xcode", value=xcode, expected_type=type_hints["xcode"])
         self._values: typing.Dict[str, typing.Any] = {
             "xcode": xcode,
         }
@@ -836,6 +890,10 @@ class Matrix:
         :see: https://circleci.com/docs/2.0/configuration-reference/#matrix-requires-version-21
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Matrix.__init__)
+            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
+            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
         self._values: typing.Dict[str, typing.Any] = {}
         if alias is not None:
             self._values["alias"] = alias
@@ -898,6 +956,11 @@ class PipelineParameter:
         :see: https://circleci.com/docs/2.0/reusing-config#using-the-parameters-declaration
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PipelineParameter.__init__)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument default", value=default, expected_type=type_hints["default"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
         self._values: typing.Dict[str, typing.Any] = {
             "type": type,
         }
@@ -1058,6 +1121,16 @@ class Run:
         :see: https://circleci.com/docs/2.0/configuration-reference/#run
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Run.__init__)
+            check_type(argname="argument command", value=command, expected_type=type_hints["command"])
+            check_type(argname="argument background", value=background, expected_type=type_hints["background"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument no_output_timeout", value=no_output_timeout, expected_type=type_hints["no_output_timeout"])
+            check_type(argname="argument shell", value=shell, expected_type=type_hints["shell"])
+            check_type(argname="argument when", value=when, expected_type=type_hints["when"])
+            check_type(argname="argument working_directory", value=working_directory, expected_type=type_hints["working_directory"])
         self._values: typing.Dict[str, typing.Any] = {
             "command": command,
         }
@@ -1172,7 +1245,7 @@ class Schedule:
     def __init__(
         self,
         *,
-        filters: Filter,
+        filters: typing.Union[Filter, typing.Dict[str, typing.Any]],
         cron: typing.Optional[builtins.str] = None,
     ) -> None:
         '''(experimental) A workflow may have a schedule indicating it runs at a certain time.
@@ -1185,6 +1258,10 @@ class Schedule:
         '''
         if isinstance(filters, dict):
             filters = Filter(**filters)
+        if __debug__:
+            type_hints = typing.get_type_hints(Schedule.__init__)
+            check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
+            check_type(argname="argument cron", value=cron, expected_type=type_hints["cron"])
         self._values: typing.Dict[str, typing.Any] = {
             "filters": filters,
         }
@@ -1227,7 +1304,11 @@ class Schedule:
     name_mapping={"run": "run"},
 )
 class StepRun:
-    def __init__(self, *, run: typing.Optional[Run] = None) -> None:
+    def __init__(
+        self,
+        *,
+        run: typing.Optional[typing.Union[Run, typing.Dict[str, typing.Any]]] = None,
+    ) -> None:
         '''(experimental) Execution steps for Job.
 
         :param run: 
@@ -1237,6 +1318,9 @@ class StepRun:
         '''
         if isinstance(run, dict):
             run = Run(**run)
+        if __debug__:
+            type_hints = typing.get_type_hints(StepRun.__init__)
+            check_type(argname="argument run", value=run, expected_type=type_hints["run"])
         self._values: typing.Dict[str, typing.Any] = {}
         if run is not None:
             self._values["run"] = run
@@ -1267,7 +1351,11 @@ class StepRun:
     name_mapping={"schedule": "schedule"},
 )
 class Triggers:
-    def __init__(self, *, schedule: typing.Optional[Schedule] = None) -> None:
+    def __init__(
+        self,
+        *,
+        schedule: typing.Optional[typing.Union[Schedule, typing.Dict[str, typing.Any]]] = None,
+    ) -> None:
         '''(experimental) Specifies which triggers will cause this workflow to be executed.
 
         Default behavior is to trigger the workflow when pushing to a branch.
@@ -1279,6 +1367,9 @@ class Triggers:
         '''
         if isinstance(schedule, dict):
             schedule = Schedule(**schedule)
+        if __debug__:
+            type_hints = typing.get_type_hints(Triggers.__init__)
+            check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
         self._values: typing.Dict[str, typing.Any] = {}
         if schedule is not None:
             self._values["schedule"] = schedule
@@ -1318,8 +1409,8 @@ class Workflow:
         self,
         *,
         identifier: builtins.str,
-        jobs: typing.Optional[typing.Sequence["WorkflowJob"]] = None,
-        triggers: typing.Optional[typing.Sequence[Triggers]] = None,
+        jobs: typing.Optional[typing.Sequence[typing.Union["WorkflowJob", typing.Dict[str, typing.Any]]]] = None,
+        triggers: typing.Optional[typing.Sequence[typing.Union[Triggers, typing.Dict[str, typing.Any]]]] = None,
         when: typing.Any = None,
     ) -> None:
         '''(experimental) Used for orchestrating all jobs.
@@ -1336,6 +1427,12 @@ class Workflow:
         :see: https://circleci.com/docs/2.0/configuration-reference/#workflows
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Workflow.__init__)
+            check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
+            check_type(argname="argument jobs", value=jobs, expected_type=type_hints["jobs"])
+            check_type(argname="argument triggers", value=triggers, expected_type=type_hints["triggers"])
+            check_type(argname="argument when", value=when, expected_type=type_hints["when"])
         self._values: typing.Dict[str, typing.Any] = {
             "identifier": identifier,
         }
@@ -1416,8 +1513,8 @@ class WorkflowJob:
         *,
         identifier: builtins.str,
         context: typing.Optional[typing.Sequence[builtins.str]] = None,
-        filters: typing.Optional[Filter] = None,
-        matrix: typing.Optional[Matrix] = None,
+        filters: typing.Optional[typing.Union[Filter, typing.Dict[str, typing.Any]]] = None,
+        matrix: typing.Optional[typing.Union[Matrix, typing.Dict[str, typing.Any]]] = None,
         name: typing.Optional[builtins.str] = None,
         orb_parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
         requires: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -1443,6 +1540,16 @@ class WorkflowJob:
             filters = Filter(**filters)
         if isinstance(matrix, dict):
             matrix = Matrix(**matrix)
+        if __debug__:
+            type_hints = typing.get_type_hints(WorkflowJob.__init__)
+            check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
+            check_type(argname="argument context", value=context, expected_type=type_hints["context"])
+            check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
+            check_type(argname="argument matrix", value=matrix, expected_type=type_hints["matrix"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument orb_parameters", value=orb_parameters, expected_type=type_hints["orb_parameters"])
+            check_type(argname="argument requires", value=requires, expected_type=type_hints["requires"])
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
         self._values: typing.Dict[str, typing.Any] = {
             "identifier": identifier,
         }
