@@ -8,6 +8,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
 from .. import (
@@ -52,6 +54,9 @@ class DevContainer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DevContainer.__init__)
+            check_type(argname="argument project", value=project, expected_type=type_hints["project"])
         options = DevContainerOptions(
             docker_image=docker_image,
             ports=ports,
@@ -69,6 +74,9 @@ class DevContainer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DevContainer.add_docker_image)
+            check_type(argname="argument image", value=image, expected_type=type_hints["image"])
         return typing.cast(None, jsii.invoke(self, "addDockerImage", [image]))
 
     @jsii.member(jsii_name="addPorts")
@@ -79,6 +87,9 @@ class DevContainer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DevContainer.add_ports)
+            check_type(argname="argument ports", value=ports, expected_type=typing.Tuple[type_hints["ports"], ...])
         return typing.cast(None, jsii.invoke(self, "addPorts", [*ports]))
 
     @jsii.member(jsii_name="addTasks")
@@ -91,6 +102,9 @@ class DevContainer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DevContainer.add_tasks)
+            check_type(argname="argument tasks", value=tasks, expected_type=typing.Tuple[type_hints["tasks"], ...])
         return typing.cast(None, jsii.invoke(self, "addTasks", [*tasks]))
 
     @jsii.member(jsii_name="addVscodeExtensions")
@@ -101,6 +115,9 @@ class DevContainer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DevContainer.add_vscode_extensions)
+            check_type(argname="argument extensions", value=extensions, expected_type=typing.Tuple[type_hints["extensions"], ...])
         return typing.cast(None, jsii.invoke(self, "addVscodeExtensions", [*extensions]))
 
     @builtins.property # type: ignore[misc]
@@ -144,6 +161,12 @@ class DevContainerOptions(_DevEnvironmentOptions_b10d89d1):
         :see: https://github.com/microsoft/vscode-dev-containers/tree/master/containers/codespaces-linux
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DevContainerOptions.__init__)
+            check_type(argname="argument docker_image", value=docker_image, expected_type=type_hints["docker_image"])
+            check_type(argname="argument ports", value=ports, expected_type=type_hints["ports"])
+            check_type(argname="argument tasks", value=tasks, expected_type=type_hints["tasks"])
+            check_type(argname="argument vscode_extensions", value=vscode_extensions, expected_type=type_hints["vscode_extensions"])
         self._values: typing.Dict[str, typing.Any] = {}
         if docker_image is not None:
             self._values["docker_image"] = docker_image
@@ -244,6 +267,11 @@ class Presentation:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Presentation.__init__)
+            check_type(argname="argument group", value=group, expected_type=type_hints["group"])
+            check_type(argname="argument hidden", value=hidden, expected_type=type_hints["hidden"])
+            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
         self._values: typing.Dict[str, typing.Any] = {
             "group": group,
             "hidden": hidden,
@@ -310,6 +338,11 @@ class ServerReadyAction:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ServerReadyAction.__init__)
+            check_type(argname="argument action", value=action, expected_type=type_hints["action"])
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
+            check_type(argname="argument uri_format", value=uri_format, expected_type=type_hints["uri_format"])
         self._values: typing.Dict[str, typing.Any] = {
             "action": action,
         }
@@ -370,6 +403,9 @@ class VsCode(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(VsCode.__init__)
+            check_type(argname="argument project", value=project, expected_type=type_hints["project"])
         jsii.create(self.__class__, self, [project])
 
     @builtins.property # type: ignore[misc]
@@ -397,6 +433,9 @@ class VsCodeLaunchConfig(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(VsCodeLaunchConfig.__init__)
+            check_type(argname="argument vscode", value=vscode, expected_type=type_hints["vscode"])
         jsii.create(self.__class__, self, [vscode])
 
     @jsii.member(jsii_name="addConfiguration")
@@ -412,10 +451,10 @@ class VsCodeLaunchConfig(
         out_files: typing.Optional[typing.Sequence[builtins.str]] = None,
         post_debug_task: typing.Optional[builtins.str] = None,
         pre_launch_task: typing.Optional[builtins.str] = None,
-        presentation: typing.Optional[Presentation] = None,
+        presentation: typing.Optional[typing.Union[Presentation, typing.Dict[str, typing.Any]]] = None,
         program: typing.Optional[builtins.str] = None,
         runtime_args: typing.Optional[typing.Sequence[builtins.str]] = None,
-        server_ready_action: typing.Optional[ServerReadyAction] = None,
+        server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[str, typing.Any]]] = None,
         skip_files: typing.Optional[typing.Sequence[builtins.str]] = None,
         url: typing.Optional[builtins.str] = None,
         web_root: typing.Optional[builtins.str] = None,
@@ -498,10 +537,10 @@ class VsCodeLaunchConfigurationEntry:
         out_files: typing.Optional[typing.Sequence[builtins.str]] = None,
         post_debug_task: typing.Optional[builtins.str] = None,
         pre_launch_task: typing.Optional[builtins.str] = None,
-        presentation: typing.Optional[Presentation] = None,
+        presentation: typing.Optional[typing.Union[Presentation, typing.Dict[str, typing.Any]]] = None,
         program: typing.Optional[builtins.str] = None,
         runtime_args: typing.Optional[typing.Sequence[builtins.str]] = None,
-        server_ready_action: typing.Optional[ServerReadyAction] = None,
+        server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[str, typing.Any]]] = None,
         skip_files: typing.Optional[typing.Sequence[builtins.str]] = None,
         url: typing.Optional[builtins.str] = None,
         web_root: typing.Optional[builtins.str] = None,
@@ -531,6 +570,24 @@ class VsCodeLaunchConfigurationEntry:
             presentation = Presentation(**presentation)
         if isinstance(server_ready_action, dict):
             server_ready_action = ServerReadyAction(**server_ready_action)
+        if __debug__:
+            type_hints = typing.get_type_hints(VsCodeLaunchConfigurationEntry.__init__)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument args", value=args, expected_type=type_hints["args"])
+            check_type(argname="argument debug_server", value=debug_server, expected_type=type_hints["debug_server"])
+            check_type(argname="argument internal_console_options", value=internal_console_options, expected_type=type_hints["internal_console_options"])
+            check_type(argname="argument out_files", value=out_files, expected_type=type_hints["out_files"])
+            check_type(argname="argument post_debug_task", value=post_debug_task, expected_type=type_hints["post_debug_task"])
+            check_type(argname="argument pre_launch_task", value=pre_launch_task, expected_type=type_hints["pre_launch_task"])
+            check_type(argname="argument presentation", value=presentation, expected_type=type_hints["presentation"])
+            check_type(argname="argument program", value=program, expected_type=type_hints["program"])
+            check_type(argname="argument runtime_args", value=runtime_args, expected_type=type_hints["runtime_args"])
+            check_type(argname="argument server_ready_action", value=server_ready_action, expected_type=type_hints["server_ready_action"])
+            check_type(argname="argument skip_files", value=skip_files, expected_type=type_hints["skip_files"])
+            check_type(argname="argument url", value=url, expected_type=type_hints["url"])
+            check_type(argname="argument web_root", value=web_root, expected_type=type_hints["web_root"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "request": request,
